@@ -6,19 +6,29 @@ import thermosteam as tmo
 from flexsolve import IQ_interpolation
 from .utils import copy_maybe, to_searchable_format
 from .properties.identifiers import CAS_from_any, pubchem_db
-from .properties.vapor_pressure import VaporPressure
-from .properties.phase_change import Tb, Tm, Hfus, Hsub, EnthalpyVaporization
-from .properties.critical import Tc, Pc, Vc
-from .properties.acentric import omega, StielPolar
-from .properties.triple import Tt, Pt
-from .properties.volume import Volume
-from .properties.heat_capacity import HeatCapacity
-from .properties.reaction import Hf
+from .properties.vapor_pressure import vapor_pressure_handle
+from .properties.phase_change import (normal_boiling_point_temperature,
+                                      normal_melting_point_temperature,
+                                      heat_of_fusion,
+                                      heat_of_sublimation,
+                                      heat_of_vaporization_handle)
+from .properties.critical import (Ihmels,
+                                  critical_point_temperature,
+                                  critical_point_pressure,
+                                  critical_point_volume)
+from .properties.acentric import (acentric_factor,
+                                  compute_acentric_factor,
+                                  estimate_acentric_factor_LK,
+                                  compute_Stiel_Polar)
+from .properties.triple import triple_point_temperature, triple_point_pressure
+from .properties.volume import volume_handle
+from .properties.heat_capacity import heat_capacity_handle
+from .properties.reaction import heat_of_formation
 from .properties.combustion import CombustionData
 from .properties.elements import compute_similarity_variable, parse_simple_formula
 from .properties.eos import GCEOS_DUMMY, PR
-from .properties.viscosity import Viscosity
-from .properties.thermal_conductivity import ThermalConductivity
+from .properties.viscosity import viscosity_handle
+from .properties.thermal_conductivity import thermal_conductivity_handle
 from .properties.free_energy import \
     EnthalpyRefSolid, EnthalpyRefLiquid, EnthalpyRefGas, \
     EntropyRefSolid, EntropyRefLiquid, EntropyRefGas, \
@@ -28,13 +38,14 @@ from .base import PhaseProperty, PhaseTProperty, PhaseTPProperty, \
                   ThermoModelHandle, TDependentModelHandle, TPDependentModelHandle, \
                   display_asfunctor
 from .base.units_of_measure import chemical_units_of_measure
-from .properties.dipole import dipole_moment as dipole
+from .properties.dipole import dipole_moment
 from . import functional as fn 
-from .properties.permittivity import Permittivity
-from .properties.interface import SurfaceTension
+from .properties.permittivity import permitivity_handle
+from .properties.interface import surface_tension_handle
 from .equilibrium.unifac_data import \
     DDBST_UNIFAC_assignments, DDBST_MODIFIED_UNIFAC_assignments, DDBST_PSRK_assignments, \
     UNIFACGroupCounts, DortmundGroupCounts, PSRKGroupCounts
+from .exceptions import DomainError
 # from .solubility import SolubilityParameter
 # from .safety import Tflash, Tautoignition, LFL, UFL, TWA, STEL, Ceiling, Skin, Carcinogen
 # from .lennard_jones import Stockmayer, MolecularDiameter
@@ -127,9 +138,9 @@ _liquid_only_properties = ('sigma', 'epsilon')
 
 _equilibrium_properties = ('Psat', 'Hvap')
 
-_data = ('MW', 'Tm', 'Tb', 'Tt', 'Tc', 'Pt', 'Pc', 'Vc', 'Zc',
+_data = ('MW', 'Tm', 'Tb', 'Tt', 'Tc', 'Pt', 'Pc', 'Vc',
          'Hf', 'LHV', 'HHV', 'Hfus', 'Hsub', 'omega', 'dipole',
-         'StielPolar', 'similarity_variable', 'iscyclic_aliphatic')
+         'similarity_variable', 'iscyclic_aliphatic')
 
 _checked_slots = ('phase_ref', 'eos', 'eos_1atm',
                   *_names[1:], *_groups, *_reactions,
@@ -198,18 +209,16 @@ class Chemical:
              Tb: 373.12 K
              Tt: 273.15 K
              Tc: 647.14 K
-             Pt: None
+             Pt: 610.88 Pa
              Pc: 2.2048e+07 Pa
              Vc: 5.6e-05 m^3/mol
-             Zc: 0.22947
              Hf: -2.4182e+05 J/mol
              LHV: 0
              HHV: 0
              Hfus: 6010 J/mol
              Hsub: None
              omega: 0.344
-             dipole: 1.85 Debye
-             StielPolar: None
+             dipole: None
              similarity_variable: 0.16653
              iscyclic_aliphatic: 0
 
@@ -233,7 +242,7 @@ class Chemical:
     0.07205503890847455
     >>> # Molar volume (m^3/mol)
     >>> Water.V(phase='l', T=298.15, P=101325)
-    1.802828527066713e-05
+    1.806920448788909e-05
     
     Note that the reference state of all chemicals is 25 degC and 1 atm:
     
@@ -466,8 +475,6 @@ class Chemical:
         Critical point pressure [Pa].
     Vc : float
         Critical point molar volume [m^3/mol].
-    Zc : float
-        Critical point molar volume [m^3/mol].
     Hf : float
         Heat of formation [J/mol].
     LHV : float
@@ -482,8 +489,6 @@ class Chemical:
         Accentric factor [-].
     dipole : float
         Dipole moment [Debye].
-    StielPolar : float
-        Stiel Polar factor [-].
     similarity_variable : float
         Similarity variable [-].
     iscyclic_aliphatic : bool
@@ -569,6 +574,7 @@ class Chemical:
                               self.Pc, self.Zc, self.Vc, self.Hfus,
                               self.omega, self.dipole, self.similarity_variable,
                               self.iscyclic_aliphatic, self.eos, has_hydroxyl)
+        self._estimate_missing_properties()
         self._init_energies(self.Cn, self.Hvap, self.Psat, self.Hfus,
                             self.Tm, self.Tb, self.eos, self.eos_1atm,
                             phase_ref)
@@ -617,6 +623,29 @@ class Chemical:
         """[str] CAS number of chemical."""
         return self._CAS
     
+    @property
+    def Stiel_Polar(self):
+        """[float] Stiel Polar factor for computing surface tension."""
+        Psat = self.Psat
+        omega = self.omega
+        Tc = self.Tc
+        Pc = self.Pc
+        if all([Psat, omega, Tc, Pc]):
+            P_at_Tr_sixtenths = Psat.try_out(0.6 * Tc)
+            if P_at_Tr_sixtenths:
+                Stiel_Polar = compute_Stiel_Polar(P_at_Tr_sixtenths, omega, Pc)
+            else:
+                Stiel_Polar = None
+        else:
+            Stiel_Polar = None
+        return Stiel_Polar
+    
+    @property
+    def Zc(self):
+        """[float] Compressibility factor."""
+        critical_point = (self.Tc, self.Pc, self.Vc)
+        return fn.Z(*critical_point) if all(critical_point) else None
+    
     def get_atoms(self):
         """dict[str: int] Atom-count pairs."""
         return parse_simple_formula(self.formula)
@@ -625,6 +654,7 @@ class Chemical:
         """Return the saturated temperature (in Kelvin) given the pressure (in Pascal)."""
         Tb = self.Tb
         Psat = self.Psat
+        if not Psat: return None
         if not Tmin: Tmin = Psat.Tmin 
         if not Tmax: Tmax = Psat.Tmax
         if Tb:
@@ -634,7 +664,10 @@ class Chemical:
                 Tguess = Tb * (P / 101325)
         elif not Tguess:
             Tguess = (Tmin + Tmax)/2
-        return IQ_interpolation(Psat, Tmin, Tmax, 0, Psat(Tmax-1e-4), Tguess, P, 1e-2, 1e-1)
+        try:
+            return IQ_interpolation(Psat, Tmin, Tmax, 0, Psat(Tmax-1e-4), Tguess, P, 1e-3, 1e-1)
+        except DomainError:
+            return None
 
     def copy(self, ID, CAS=None):
         """Return a copy of the chemical with a new ID."""
@@ -683,26 +716,25 @@ class Chemical:
 
     def _init_data(self, CAS, atoms, MW):
         self.MW = MW
-        self.Tm = Tm(CAS)
-        self.Tb = Tb(CAS)
+        self.Tm = normal_melting_point_temperature(CAS)
+        self.Tb = Tb = normal_boiling_point_temperature(CAS)
 
         # Critical Point
-        self.Tc = Tc(CAS)
-        self.Pc = Pc(CAS)
-        self.Vc = Vc(CAS)
-        self.omega = omega(CAS)
-        self.Zc = fn.Z(self.Tc, self.Pc, self.Vc) if all((self.Tc, self.Pc, self.Vc)) else None
+        self.Tc = Tc = critical_point_temperature(CAS)
+        self.Pc = Pc = critical_point_pressure(CAS)
+        self.Vc = critical_point_volume(CAS)
+        self.omega = acentric_factor(CAS, Tb, Tc, Pc)
 
         # Triple point
-        self.Pt = Pt(CAS)
-        self.Tt = Tt(CAS)
+        self.Pt = triple_point_pressure(CAS)
+        self.Tt = triple_point_temperature(CAS)
 
         # Energy
-        self.Hfus = Hfus(CASRN=CAS, MW=MW)
-        self.Hsub = Hsub(CASRN=CAS)
+        self.Hfus = heat_of_fusion(CAS)
+        self.Hsub = heat_of_sublimation(CAS)
 
         # Chemistry
-        self.Hf = Hf(CAS) or None
+        self.Hf = heat_of_formation(CAS)
         try:
             CD = CombustionData.from_chemical_data(atoms, self.CAS, MW, self.Hf)
         except:
@@ -712,11 +744,8 @@ class Chemical:
             self.HHV = CD.HHV
             self.combustion = CD.stoichiometry
         
-        # Critical Point
-        self.StielPolar = StielPolar(CAS, Tc, Pc, omega)
-        
         # Other
-        self.dipole = dipole(CAS)
+        self.dipole = dipole_moment(CAS)
         self.similarity_variable = compute_similarity_variable(atoms, MW)
         self.iscyclic_aliphatic = False
 
@@ -728,34 +757,36 @@ class Chemical:
                          dipole, similarity_variable, iscyclic_aliphatic, eos,
                          has_hydroxyl):
         # Vapor pressure
-        self.Psat = Psat = VaporPressure((CAS, Tb, Tc, Pc, omega))
+        data = (CAS, Tb, Tc, Pc, omega)
+        self.Psat = Psat = vapor_pressure_handle(data)
+        if not Tb: Tb = self.Tsat(101325)
         
         # Volume
         sdata = (CAS,)
         ldata = (CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, Psat, eos, dipole, has_hydroxyl)
         gdata = (CAS, Tc, Pc, omega, eos)
-        self.V = V = Volume(sdata, ldata, gdata)
+        self.V = V = volume_handle(sdata, ldata, gdata)
         
         # Heat capacity
         Cn = PhaseTProperty('Cn')
         sdata = (CAS, similarity_variable, MW)
         ldata = (CAS, Tb, Tc, omega, MW, similarity_variable, Cn)
         gdata = (CAS, MW, similarity_variable, iscyclic_aliphatic)
-        self.Cn = Cn = HeatCapacity(sdata, ldata, gdata, Cn)
+        self.Cn = Cn = heat_capacity_handle(sdata, ldata, gdata, Cn)
         
         # Heat of vaporization
         data = (CAS, Tb, Tc, Pc, omega, similarity_variable, Psat, V)
-        self.Hvap = Hvap = EnthalpyVaporization(data)
+        self.Hvap = Hvap = heat_of_vaporization_handle(data)
         
         # Viscosity
         ldata = (CAS, MW, Tm, Tc, Pc, Vc, omega, Psat, V.l)
         gdata = (CAS, MW, Tc, Pc, Zc, dipole)
-        self.mu = mu = Viscosity(None, ldata, gdata)
+        self.mu = mu = viscosity_handle(None, ldata, gdata)
         
         # Conductivity
         ldata = (CAS, MW, Tm, Tb, Tc, Pc, omega, Hfus)
         gdata = (CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, dipole, V.g, Cn.g, mu.g)
-        self.kappa = ThermalConductivity(None, ldata, gdata)
+        self.kappa = thermal_conductivity_handle(None, ldata, gdata)
         
         # Surface tension
         if Tb:
@@ -768,14 +799,50 @@ class Chemical:
         else:
             Hvap_Tb = Cnl_Tb = rhol = None
         data = (CAS, MW, Tb, Tc, Pc, Vc, Zc,
-                omega, StielPolar, Hvap_Tb, rhol, Cnl_Tb)
-        self.sigma = SurfaceTension(data)
+                omega, self.Stiel_Polar, Hvap_Tb, rhol, Cnl_Tb)
+        self.sigma = surface_tension_handle(data)
         
         # Other
-        self.epsilon = Permittivity((CAS, V.l,))
+        self.epsilon = permitivity_handle((CAS, V.l,))
         # self.delta = SolubilityParameter(self)
         # self.molecular_diameter = MolecularDiameter(self)
 
+    def _estimate_missing_properties(self):
+        # Melting temperature is a week function of pressure,
+        # so assume the triple point temperature is the 
+        # melting temperature
+        Tm = self.Tm
+        Tt = self.Tt
+        Pt = self.Pt
+        Tc = self.Tc
+        Pc = self.Pc
+        Vc = self.Vc
+        if not Tm and Tt:
+            self.Tm = Tm = Tt
+        if not Tt and Tm:
+            self.Tt = Tt = Tm
+        if not Pt and Tt:
+            self.Pt = Pt = self.Psat.try_out(Tt)
+        
+        # Find missing critical property, if only two are given.
+        critical_point = (Tc, Pc, Vc)
+        N_values = sum([bool(i) for i in critical_point])
+        if N_values == 2:
+            self.Tc, self.Pc, self.Vc = Tc, Pc, Vc = Ihmels(*critical_point)
+            
+        Tb = self.Tb
+        if not Tb:
+            self.Tb = Tb = self.Tsat(101325)
+            
+        omega = self.omega
+        if not omega and Pc and Tc:
+            P_at_Tr_seventenths = self.Psat.try_out(0.7 * Tc)
+            if P_at_Tr_seventenths:
+                omega = compute_acentric_factor(P_at_Tr_seventenths, Pc)
+            if not omega and Tb:
+                omega = estimate_acentric_factor_LK(Tb, Tc, Pc)
+            self.omega = omega
+
     def _init_energies(self, Cn, Hvap, Psat, Hfus, Tm, Tb, eos, eos_1atm,
                        phase_ref=None, single_phase=False):        
         # Reference
@@ -942,7 +1009,7 @@ class Chemical:
         
         Returns
         -------
-        missing_slots : list[str]
+        missing_slots : set[str]
             Names of chemical properties that are still missing.
         
         Examples
@@ -951,7 +1018,7 @@ class Chemical:
         >>> Substance = Chemical.blank('Substance')
         >>> missing_slots = Substance.default()
         >>> sorted(missing_slots)
-        ['Dortmund', 'Hfus', 'Hsub', 'Hvap', 'InChI', 'InChI_key', 'PSRK', 'Pc', 'Psat', 'Pt', 'StielPolar', 'Tb', 'Tc', 'Tm', 'Tt', 'UNIFAC', 'V', 'Vc', 'Zc', 'combustion', 'common_name', 'dipole', 'eos', 'eos_1atm', 'formula', 'iscyclic_aliphatic', 'iupac_name', 'omega', 'pubchemid', 'similarity_variable', 'smiles']
+        ['Dortmund', 'Hfus', 'Hsub', 'Hvap', 'InChI', 'InChI_key', 'PSRK', 'Pc', 'Psat', 'Pt', 'Tb', 'Tc', 'Tm', 'Tt', 'UNIFAC', 'V', 'Vc', 'combustion', 'common_name', 'dipole', 'eos', 'eos_1atm', 'formula', 'iscyclic_aliphatic', 'iupac_name', 'omega', 'pubchemid', 'similarity_variable', 'smiles']
         
         Note that missing slots does not include essential properties volume, heat capacity, and conductivity.
         
@@ -1058,7 +1125,7 @@ class Chemical:
         >>> from thermosteam import Chemical
         >>> Substance = Chemical.blank('Substance', phase_ref='l')
         >>> Substance.get_missing_slots()
-        ['eos', 'eos_1atm', 'InChI', 'InChI_key', 'common_name', 'iupac_name', 'pubchemid', 'smiles', 'formula', 'Dortmund', 'UNIFAC', 'PSRK', 'combustion', 'S_excess', 'H_excess', 'mu', 'kappa', 'V', 'S', 'H', 'Cn', 'Psat', 'Hvap', 'sigma', 'epsilon', 'MW', 'Tm', 'Tb', 'Tt', 'Tc', 'Pt', 'Pc', 'Vc', 'Zc', 'Hf', 'LHV', 'HHV', 'Hfus', 'Hsub', 'omega', 'dipole', 'StielPolar', 'similarity_variable', 'iscyclic_aliphatic']
+        ['eos', 'eos_1atm', 'InChI', 'InChI_key', 'common_name', 'iupac_name', 'pubchemid', 'smiles', 'formula', 'Dortmund', 'UNIFAC', 'PSRK', 'combustion', 'S_excess', 'H_excess', 'mu', 'kappa', 'V', 'S', 'H', 'Cn', 'Psat', 'Hvap', 'sigma', 'epsilon', 'MW', 'Tm', 'Tb', 'Tt', 'Tc', 'Pt', 'Pc', 'Vc', 'Hf', 'LHV', 'HHV', 'Hfus', 'Hsub', 'omega', 'dipole', 'similarity_variable', 'iscyclic_aliphatic']
         
         """
         getfield = getattr
@@ -1130,7 +1197,6 @@ class Chemical:
                  Pt: None
                  Pc: None
                  Vc: None
-                 Zc: None
                  Hf: None
                  LHV: None
                  HHV: None
@@ -1138,7 +1204,6 @@ class Chemical:
                  Hsub: None
                  omega: None
                  dipole: None
-                 StielPolar: None
                  similarity_variable: None
                  iscyclic_aliphatic: None
         
@@ -1232,15 +1297,13 @@ class Chemical:
                  Pt: 12527 Pa
                  Pc: 3.3944e+06 Pa
                  Vc: 8.95e-05 m^3/mol
-                 Zc: 0.28953
                  Hf: None
                  LHV: 0
                  HHV: 0
                  Hfus: 710 J/mol
                  Hsub: None
                  omega: 0.04
-                 dipole: 0 Debye
-                 StielPolar: None
+                 dipole: None
                  similarity_variable: 0.071394
                  iscyclic_aliphatic: 0
         
