@@ -12,6 +12,7 @@ from .thermo_model import (ThermoModel,
                            TPDependentModel,
                            thermo_model,
                            create_axis_labels)
+from ..exceptions import DomainError
 from .units_of_measure import definitions
 from .functor import functor_lookalike
 
@@ -33,7 +34,7 @@ def find_model_index_by_name(models, name):
     
 def no_valid_model(chemical, var):
     definition = definitions.get(var)
-    msg = f"{chemical} has no valid " if chemical else "no valid "
+    msg = f"{chemical} (CAS: {chemical.CAS}) has no valid " if chemical else "no valid "
     msg += f"{definition.lower()} model" if definition else "model"
     return msg
 
@@ -253,7 +254,11 @@ class TDependentModelHandle(ThermoModelHandle):
             if model.indomain(T): return model.evaluate(T)
         raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
                          f"at T={T:.2f} K")
-        
+    
+    def try_out(self, T, P=None):
+        for model in self.models:
+            if model.indomain(T): return model.evaluate(T)
+    
     def differentiate_by_T(self, T, P=None, dT=1e-12):
         for model in self.models:
             if model.indomain(T): return model.differentiate_by_T(T, dT=dT)
@@ -274,11 +279,7 @@ class TDependentModelHandle(ThermoModelHandle):
             ub_satisfied = Tb < Tmax
             if lb_satisfied:
                 if ub_satisfied:
-                    try:
-                        return integral + model.integrate_by_T(Ta, Tb)
-                    except:
-                        import pdb
-                        pdb.set_trace()
+                    return integral + model.integrate_by_T(Ta, Tb)
                 elif Ta < Tmax:
                     integral += model.integrate_by_T(Ta, Tmax)
                     Ta = Tmax
@@ -332,19 +333,23 @@ class TPDependentModelHandle(ThermoModelHandle):
     def __call__(self, T, P):
         for model in self.models:
             if model.indomain(T, P): return model.evaluate(T, P)
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
                          f"at T={T:.2f} K and P={P:.0f} Pa")
 
+    def try_out(self, T, P):
+        for model in self.models:
+            if model.indomain(T, P): return model.evaluate(T, P)
+
     def differentiate_by_T(self, T, P):
         for model in self.models:
             if model.indomain(T, P): return model.differentiate_by_T(T, P)
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
                          f"at T={T:.2f} K and P={P:.0f} Pa")
             
     def differentiate_by_P(self, T, P):
         for model in self.models:
              if model.indomain(T, P): return model.differentiate_by_P(T, P)
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
                          f"at T={T:.2f} K and P={P:.0f} Pa")
 
     def integrate_by_T(self, Ta, Tb, P):
@@ -365,7 +370,7 @@ class TPDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T(Tmin, Tb, P)
                 Tb = Tmin
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
                          f"between T={Ta:.2f} to {Tb:.2f} K at P={P:.0f} Pa")
     
     def integrate_by_P(self, Pa, Pb, T):
@@ -387,7 +392,7 @@ class TPDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Pmin < Pb:
                 integral += model.integrate_by_P(Pmin, Pb, T)
                 Pb = Pmin
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
                          f"between P={Pa:5g} to {Pb:5g} Pa ast T={T:.2f}")
     
     def integrate_by_T_over_T(self, Ta, Tb, P):
@@ -409,7 +414,7 @@ class TPDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T_over_T(Tmin, Tb, P)
                 Tb = Tmin
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
                          f"between T={Ta:.2f} to {Tb:.2f} K")
         
             
