@@ -4,7 +4,7 @@ Created on Wed Mar 20 18:40:05 2019
 
 @author: yoelr
 """
-from flexsolve import wegstein, IQ_interpolation, fixed_point
+from flexsolve import wegstein, IQ_interpolation, fixed_point, SolverError
 from ..utils.decorator_utils import thermo_user
 from .binary_phase_fraction import phase_fraction
 from .dew_point import DewPoint
@@ -78,12 +78,11 @@ class VLE:
                  '_index', # [1d array] Index of chemicals in equilibrium.
                  '_F_mass', # [float] Total mass data.
                  '_chemical', # [Chemical] Single chemical in equilibrium.
-                 '_mol', # [Chemical] Single chemical in equilibrium.
+                 '_mol', # [1d array] VLE chemicals in equilibrium.
                  '_N', # [int] Number of chemicals in equilibrium.
                  '_z', # [1d array] Molar composition of chemicals in equilibrium
                  '_Ks', # [1d array] Partition coefficients.
                  '_nonzero', # [1d array(bool)] Chemicals present in the mixture
-                 '_F_mol', # [float] Total molar data.
                  '_F_mol_vle', # [float] Total moles in equilibrium.
                  '_dew_point_cache', # [Cache] Retrieves the DewPoint object if arguments are the same.
                  '_bubble_point_cache') # [Cache] Retrieves the BubblePoint object if arguments are the same.
@@ -227,7 +226,6 @@ class VLE:
         liquid_mol[HNK_index] = heavy_mol = mol[HNK_index]
         F_mol_light = light_mol.sum()
         F_mol_heavy = heavy_mol.sum()
-        self._F_mol = F_mol
         self._F_mol_vle = F_mol_vle = F_mol - F_mol_light - F_mol_heavy
         self._z = self._mol / F_mol_vle
 
@@ -393,6 +391,7 @@ class VLE:
         
     def set_TV(self, T, V):
         self._setup()
+        mol = self._mol
         thermal_condition = self._thermal_condition
         thermal_condition.T = self._T = T
         if self._N == 1: return self._set_TV_chemical(T, V)
@@ -409,6 +408,7 @@ class VLE:
         else:
             self._V = V 
             self._refresh_v(V, y_bubble)
+            
             try:
                 P = self.solver(self._V_at_P,
                                 P_bubble, P_dew, 0, 1,
@@ -421,9 +421,28 @@ class VLE:
                                 P_bubble, P_dew, 0, 1,
                                 self._P, V,
                                 self.P_tol, self.V_tol)
+            
+            # In case solver cannot reach the vapor fraction because
+            # the composition does not converge at values that meets the
+            # vapor fraction.
+            V_offset = V - self._V
+            if V_offset < -1e-2:
+                F_mol_vapor = self._F_mol_vle * V
+                v = y_bubble * F_mol_vapor
+                mask = v > mol
+                v[mask] = mol[mask]
+                P = P_bubble
+            elif V_offset > 1e2:
+                v = x_dew * self._F_mol_vle * V
+                mask = v < mol 
+                v[mask] = mol[mask]
+                P = P_dew
+            else:
+                v = self._v
+            
             self._P = thermal_condition.P = P
-            self._vapor_mol[self._index] = self._v
-            self._liquid_mol[self._index] = self._mol - self._v
+            self._vapor_mol[self._index] = v
+            self._liquid_mol[self._index] = mol - v
             self._H_hat = self.mixture.xH(self._phase_data, T, P)/self._F_mass
 
     def set_TH(self, T, H):
@@ -508,6 +527,7 @@ class VLE:
         else:
             self._refresh_v(V, y_bubble)
             self._V = V 
+            
             try:
                 T = self.solver(self._V_at_T,
                                 T_bubble, T_dew, 0, 1,
@@ -519,9 +539,28 @@ class VLE:
                                 T_bubble, T_dew, 0, 1,
                                 self._T , V,
                                 self.T_tol, self.V_tol)
+            
+            # In case solver cannot reach the vapor fraction because
+            # the composition does not converge at values that meets the
+            # vapor fraction.
+            V_offset = V - self._V
+            if V_offset < -1e-2:
+                F_mol_vapor = self._F_mol_vle * V
+                v = y_bubble * F_mol_vapor
+                mask = v > mol
+                v[mask] = mol[mask]
+                T = T_bubble
+            elif V_offset > 1e2:
+                v = x_dew * self._F_mol_vle * V
+                mask = v < mol 
+                v[mask] = mol[mask]
+                T = T_dew
+            else:
+                v = self._v
+            
             self._T = thermal_condition.T = T
-            vapor_mol[index] = self._v
-            liquid_mol[index] = mol - self._v
+            vapor_mol[index] = v
+            liquid_mol[index] = mol - v
             self._H_hat = self.mixture.xH(self._phase_data, T, P)/self._F_mass
     
     def set_PH(self, P, H):
@@ -587,15 +626,15 @@ class VLE:
         return self.mixture.xH(self._phase_data, self._T, P)/self._F_mass
     
     def _V_at_P(self, P):
-        return self._solve_v(self._T , P).sum()/self._F_mol
+        return self._solve_v(self._T , P).sum()/self._F_mol_vle
     
     def _V_at_T(self, T):
-        V = self._solve_v(T, self._P).sum()/self._F_mol 
+        V = self._solve_v(T, self._P).sum()/self._F_mol_vle 
         return V
     
     def _x_iter(self, x, Psat_over_P_phi):
-        x[x < 0.] = 0.
         x = x/x.sum()
+        x[x < 1e-16] = 1e-16
         self._Ks = Psat_over_P_phi * self._gamma(x, self._T) * self._pcf(x, self._T)
         self._V = V = phase_fraction(self._z, self._Ks, self._V)
         return self._z/(1. + V * (self._Ks - 1.))
@@ -604,15 +643,16 @@ class VLE:
         phi = self._phi(y, T, P)
         Psat_over_P_phi = Psats_over_P / phi
         try:
-            self._x = x = self.itersolver(self._x_iter,
-                                          self._x, 1e-4,
-                                          args=(Psat_over_P_phi,))
-        except:
-            self._x = x = fixed_point(self._x_iter,
-                                      self._x, 1e-4,
-                                      args=(Psat_over_P_phi,))
-        self._v = v = self._F_mol_vle * self._V * x * self._Ks     
-        return v / v.sum()
+            x = self.itersolver(self._x_iter,
+                                self._x, 1e-12,
+                                args=(Psat_over_P_phi,))
+        except SolverError as solver_error:
+            x = fixed_point(self._x_iter,
+                            solver_error.x, 1e-6,
+                            args=(Psat_over_P_phi,))
+        self._x = x
+        v = self._F_mol_vle * self._V * x * self._Ks     
+        return normalize(v)
     
     def _solve_v(self, T, P):
         """Solve for vapor mol"""
@@ -620,14 +660,15 @@ class VLE:
                                  self._bubble_point.Psats]) / P
         self._T = T
         v = self._v
-        y = v / v.sum()
+        y = normalize(v)
         l = self._mol - v
         self._x = normalize(l)
         if isinstance(self._phi, IdealFugacityCoefficients):
             self._y = self._y_iter(y, Psats_over_P, T, P)
         else:
-            self._y = self.itersolver(self._y_iter, v/v.sum(), 1e-4,
+            self._y = self.itersolver(self._y_iter, v/v.sum(), 1e-6,
                                       args=(Psats_over_P, T, P))
+        self._v = self._F_mol_vle * self._V * self._y
         return self._v
 
     def __format__(self, tabs=""):
