@@ -25,8 +25,8 @@ class IdealMixtureModel:
     
     See also
     --------
-    Mixture
-    ideal_mixture
+    :class:`Mixture`
+    :func:`~.mixture_builders.ideal_mixture`
     
     Examples
     --------
