@@ -29,7 +29,8 @@ Hf_combustion_products = {
     "Ash": 0,
 }
 
-def get_combustion_stoichiometry(atoms, MW=None):
+def get_combustion_stoichiometry(atoms: dict, 
+                                 MW: float=None):
     """
     Return a dictionary of the combustion stoichiometry of a chemical.
     
@@ -74,13 +75,18 @@ def estimate_HHV_from_stoichiometry(stoichiometry, Hf):
     return sum([stoichiometry[chem] * Hf_combustion_products[chem] for chem in stoichiometry]) - Hf
 
 # TODO: Continue adding more methods for estimating HHV
-def estimate_HHV_modified_Dulong(atoms, MW=None, check_oxygen_content=False):
+def estimate_HHV_modified_Dulong(atoms: dict, MW: float=None,
+                                 check_oxygen_content: bool=False):
     r"""
     Return higher heating value [HHV; in J/mol] based on the modified 
     Dulong's equation.
     
     Parameters
     ----------
+    atoms : dict
+        Dictionary of atoms and their counts.
+    MW : float, optional
+        Molecular weight of chemical.
     
     Notes
     -----
