@@ -37,19 +37,20 @@ import os
 from io import open
 from math import log, exp
 from cmath import log as clog, exp as cexp
+from ..utils import njitable
 import numpy as np
 from ..base import InterpolatedTDependentModel, thermo_model, TDependentHandleBuilder, \
                    PhaseTPropertyBuilder, S, H, Cn
 from .utils import to_nums, CASDataReader
 from .._constants import R, calorie
 from ..functional import polylog2
-from .miscdata import _VDISaturationDict, VDI_tabular_data
+from .miscdata import VDI_saturation_dict, VDI_tabular_data
 # from .electrochem import (LaliberteHeatCapacityModel,
 #                           _Laliberte_Heat_Capacity_ParametersDict)
 # from .coolprop import has_CoolProp, coolprop_dict, CoolProp_T_dependent_property,\
 #                       coolprop_fluids, PropsSI
 
-__all__ = ('HeatCapacity',
+__all__ = ('heat_capacity_handle',
 
            'Lastovka_Shaw',
            'Lastovka_Shaw_Integral',
@@ -167,9 +168,22 @@ with open(os.path.join(read.folder, 'Perrys Table 2-151.tsv'), encoding='utf-8')
 
 
 # %% Heat Capacities Gas
+@njitable
+def calculate_Lastovka_Shaw_term(iscyclic_aliphatic, similary_variable):
+    if iscyclic_aliphatic:
+        A1 = -0.1793547
+        A2 = 3.86944439
+        term = A1 + A2 * similary_variable
+    else:
+        A1 = 0.58
+        A2 = 1.25
+        A3 = 0.17338003 # 803 instead of 8003 in another paper
+        A4 = 0.014
+        term = A2 + (A1-A2)/(1. + exp((similary_variable - A3)/A4))
+    return term
 
-@Cn.g
-def Lastovka_Shaw(T, MW, term, a):
+@Cn.g(ref="[1]_")
+def Lastovka_Shaw(T, MW, similarity_variable, iscyclic_aliphatic=False):
     r'''
     Notes
     -----
@@ -204,6 +218,8 @@ def Lastovka_Shaw(T, MW, term, a):
     33.91574477458602
     
     '''
+    a = similarity_variable
+    term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, a)
     B11 = 0.73917383
     B12 = 8.88308889
     C11 = 1188.28051
@@ -216,24 +232,15 @@ def Lastovka_Shaw(T, MW, term, a):
                  + (B11 + B12*a)*((C11+C12*a)/T)**2*exp(-(C11 + C12*a)/T)/(1.-exp(-(C11+C12*a)/T))**2
                  + (B21 + B22*a)*((C21+C22*a)/T)**2*exp(-(C21 + C22*a)/T)/(1.-exp(-(C21+C22*a)/T))**2)
 
-@Lastovka_Shaw.wrapper(ref="[1]_")
-def Lastovka_Shaw(MW, similarity_variable, iscyclic_aliphatic=False):
-    a = similarity_variable
-    if iscyclic_aliphatic:
-        A1 = -0.1793547
-        A2 = 3.86944439
-        term = A1 + A2*a
-    else:
-        A1 = 0.58
-        A2 = 1.25
-        A3 = 0.17338003 # 803 instead of 8003 in another paper
-        A4 = 0.014
-        term = A2 + (A1-A2)/(1. + exp((a - A3)/A4))
-        # Personal communication confirms the change
-    return {'MW': MW, 'term':term, 'a':a}
+@H.g
+def Lastovka_Shaw_Integral(Ta, Tb, MW, similarity_variable, iscyclic_aliphatic=False):
+    term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, a)
+    return (Lastovka_Shat_Indefinite_Integral(Tb, MW, similarity_variable, term)
+            - Lastovka_Shat_Indefinite_Integral(Ta, MW, similarity_variable, term))
 
-@H.g(wrap=Lastovka_Shaw.wrap)
-def Lastovka_Shaw_Integral(T, MW, term, a):
+@njitable
+def Lastovka_Shat_Indefinite_Integral(T, MW, similarity_variable, term=None):
+    a = similarity_variable
     B11 = 0.73917383
     B12 = 8.88308889
     C11 = 1188.28051
@@ -246,8 +253,16 @@ def Lastovka_Shaw_Integral(T, MW, term, a):
                  + C12*a)*exp((-C11 - C12*a)/T)) - (B21 + B22*a)*(-C21 - C22*a)**2/(-C21 
                  - C22*a + (C21 + C22*a)*exp((-C21 - C22*a)/T)))
 
-@S.g(wrap=Lastovka_Shaw.wrap)
-def Lastovka_Shaw_Integral_Over_T(T, MW, term, a):
+@S.g
+def Lastovka_Shaw_Integral_Over_T(Ta, Tb, MW, similarity_variable,
+                                  iscyclic_aliphatic=False):
+    term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, a)
+    return (Lastovka_Shaw_Indefinite_Integral_Over_T(Tb, MW, similarity_variable, term)
+            - Lastovka_Shaw_Indefinite_Integral_Over_T(Ta, MW, similarity_variable, term))
+
+@njitable
+def Lastovka_Shaw_Indefinite_Integral_Over_T(T, MW, similarity_variable, term):
+    a = similarity_variable
     a2 = a*a
     B11 = 0.73917383
     B12 = 8.88308889
@@ -266,7 +281,7 @@ def Lastovka_Shaw_Integral_Over_T(T, MW, term, a):
     # There is a non-real component, but it is only a function of similariy 
     # variable and so will always cancel out.
     return MW * S.real
-    
+
 @Cn.g(ref="[2]_")
 def TRCCn(T, a0, a1, a2, a3, a4, a5, a6, a7):
     r'''
@@ -307,6 +322,7 @@ def TRCCn(T, a0, a1, a2, a3, a4, a5, a6, a7):
         y = (T - a7)/(T + a6)
     return R*(a0 + (a1/T**2)*exp(-a2/T) + a3*y**2 + (a4 - a5/(T-a7)**2 )*y**8.)
 
+@njitable
 def TRCCn_Indefinite_Integral(T, a0, a1, a2, a3, a4, a5, a6, a7):
     first = a6 + a7    
     y = 0. if T <= a7 else (T - a7)/(T + a6)
@@ -327,6 +343,7 @@ def TRCCn_Integral(Ta, Tb, a0, a1, a2, a3, a4, a5, a6, a7):
     return (TRCCn_Indefinite_Integral(Tb, a0, a1, a2, a3, a4, a5, a6, a7)
             - TRCCn_Indefinite_Integral(Ta, a0, a1, a2, a3, a4, a5, a6, a7))
 
+@njitable
 def TRCCn_Over_T_Indefinite_Integral(T, a0, a1, a2, a3, a4, a5, a6, a7):
     # Possible optimizations: pre-cache as much as possible.
     # If this were replaced by a cache, much of this would not need to be computed.
@@ -382,14 +399,16 @@ def Poling(T, a, b, c, d, e):
     """
     return R*(a + b*T + c*T**2 + d*T**3 + e*T**4)
 
+@njitable
 def Poling_Indefinite_Integral(T, a, b, c, d, e):
     return (((((0.2*e)*T + 0.25*d)*T + c/3.)*T + 0.5*b)*T + a)*T
 
 @H.g
 def Poling_Integral(Ta, Tb, a, b, c, d, e):
     return R*(Poling_Indefinite_Integral(Tb, a, b, c, d, e)
-              - Poling_Indefinite_Integral(Tb, a, b, c, d, e))
+              - Poling_Indefinite_Integral(Ta, a, b, c, d, e))
 
+@njitable
 def Poling_Over_T_Indefinite_Integral(T, a, b, c, d, e):
     return ((((0.25*e)*T + d/3.)*T + 0.5*c)*T + b)*T
 
@@ -416,7 +435,7 @@ Poling_Functors = (Poling,
 
 
 @TDependentHandleBuilder('Cn.g')
-def HeatCapacityGas(handle, CAS, MW, similarity_variable, iscyclic_aliphatic):
+def heat_capacity_gas_handle(handle, CAS, MW, similarity_variable, iscyclic_aliphatic):
     add_model = handle.add_model
     if CAS in _TRC_gas:
         _, Tmin, Tmax, a0, a1, a2, a3, a4, a5, a6, a7, _, _, _ = _TRC_gas[CAS]
@@ -436,7 +455,7 @@ def HeatCapacityGas(handle, CAS, MW, similarity_variable, iscyclic_aliphatic):
     if MW and similarity_variable:
         data = (MW, similarity_variable, iscyclic_aliphatic)
         add_model(Lastovka_Shaw.from_args(data), name=LASTOVKA_SHAW)
-    if CAS in _VDISaturationDict:
+    if CAS in VDI_saturation_dict:
         # NOTE: VDI data is for the saturation curve, i.e. at increasing
         # pressure; it is normally substantially higher than the ideal gas
         # value
@@ -510,8 +529,8 @@ def Rowlinson_Bondi(T, Tc, ω, Cn_g):
     Tr = T/Tc
     return Cn_g(T) + R*(1.45 + 0.45/(1.-Tr) + 0.25*ω*(17.11 + 25.2*(1-Tr)**(1/3.)/Tr + 1.742/(1.-Tr)))
 
-@Cn.l
-def Dadgostar_Shaw(T, MW, first, second, third):
+@Cn.l(ref="[6]_")
+def Dadgostar_Shaw(T, MW, similarity_variable):
     r'''
     Notes
     -----
@@ -530,11 +549,12 @@ def Dadgostar_Shaw(T, MW, first, second, third):
     a31 = -9.8231E-05; a32 = 4.182E-04
       
     '''
+    first, second, third = calculate_Dadgostar_Shaw_terms(MW, similarity_variable)
     first *= 3*R*(151.8675/T)**2*exp(151.8675/T)/(exp(151.8675/T)-1)**2
     return (first + second*T + third*T**2) * MW
 
-@Dadgostar_Shaw.wrapper(ref="[6]_")
-def Dadgostar_Shaw(similarity_variable, MW):
+@njitable
+def calculate_Dadgostar_Shaw_terms(MW, similarity_variable):
     a = similarity_variable
     a2 = a*a
     a11 = -0.3416
@@ -546,31 +566,32 @@ def Dadgostar_Shaw(similarity_variable, MW):
     # Didn't seem to improve the comparison; sum of errors on some
     # points included went from 65.5  to 286.
     # Author probably used more precision in their calculation.
-    return {'MW': MW,
-            'first': a11*a + a12*a2,
-            'second': a21*a + a22*a2,
-            'third': a31*a + a32*a2}
+    return (a11*a + a12*a2,
+            a21*a + a22*a2,
+            a31*a + a32*a2)
 
-
-def Dadgostar_Shaw_Indefinte_Integral(T, MW, first, second, third):
+@njitable
+def Dadgostar_Shaw_Indefinte_Integral(T, first, second, third):
     T2 = T*T
     first *= 3*R*(151.8675/T)**2*exp(151.8675/T)/(exp(151.8675/T)-1)**2
     return T2*T/3.*third + T2*0.5*second + T*first
 
-@H.l(wrap=Dadgostar_Shaw.wrap)
-def Dadgostar_Shaw_Integral(Ta, Tb, MW, first, second, third):
-    return MW*(Dadgostar_Shaw_Indefinte_Integral(Tb, MW, first, second, third)
-               - Dadgostar_Shaw_Indefinte_Integral(Ta, MW, first, second, third))
+@H.l
+def Dadgostar_Shaw_Integral(Ta, Tb, MW, similarity_variable):
+    terms = calculate_Dadgostar_Shaw_terms(MW, similarity_variable)
+    return MW*(Dadgostar_Shaw_Indefinte_Integral(Tb, *terms)
+               - Dadgostar_Shaw_Indefinte_Integral(Ta, *terms))
 
-
-def Dadgostar_Shaw_Over_T_Indefinte_Integral(T, MW, first, second, third):
+@njitable
+def Dadgostar_Shaw_Over_T_Indefinte_Integral(T, first, second, third):
     first *= 3*R*(151.8675/T)**2*exp(151.8675/T)/(exp(151.8675/T)-1)**2
     return T*T*0.5*third + T*second + first*log(T)
 
-@H.l(wrap=Dadgostar_Shaw.wrap) 
-def Dadgostar_Shaw_Over_T_Integral(Ta, Tb, MW, first, second, third):
-    return MW*(Dadgostar_Shaw_Over_T_Indefinte_Integral(Tb, MW, first, second, third)
-               - Dadgostar_Shaw_Over_T_Indefinte_Integral(Ta, MW, first, second, third))
+@H.l
+def Dadgostar_Shaw_Over_T_Integral(Ta, Tb, MW, similarity_variable):
+    terms = calculate_Dadgostar_Shaw_terms(MW, similarity_variable)
+    return MW*(Dadgostar_Shaw_Over_T_Indefinte_Integral(Tb, *terms)
+               - Dadgostar_Shaw_Over_T_Indefinte_Integral(Ta, *terms))
 
 zabransky_dict_sat_s = {}
 zabransky_dict_sat_p = {}
@@ -582,7 +603,7 @@ zabransky_dict_iso_p = {}
 # C means average heat capacity values, from less rigorous experiments
 # sat means heat capacity along the saturation line
 # p means constant-pressure values, 
-# True means it has a splie, False otherwise
+# second argument is whether or not it has a spline
 type_to_zabransky_dict = {('C', True): zabransky_dict_const_s, 
                           ('C', False):   zabransky_dict_const_p,
                           ('sat', True):  zabransky_dict_sat_s,
@@ -626,6 +647,7 @@ def Zabransky_Quasi_Polynomial(T, Tc, a1, a2, a3, a4, a5, a6):
     Tr = T/Tc
     return R*(a1*log(1-Tr) + a2/(1-Tr) + a3 + a4*Tr + a5*Tr**2 + a6*Tr**3)
 
+@njitable
 def Zabransky_Quasi_Polynomial_Indefinte_Integral(T, Tc, a1, a2, a3, a4, a5, a6):
     Tc2 = Tc*Tc
     Tc3 = Tc2*Tc    
@@ -638,7 +660,7 @@ def Zabransky_Quasi_Polynomial_Integral(Ta, Tb, Tc, a1, a2, a3, a4, a5, a6):
     return (Zabransky_Quasi_Polynomial_Indefinte_Integral(Tb, Tc, a1, a2, a3, a4, a5, a6)
             - Zabransky_Quasi_Polynomial_Indefinte_Integral(Ta, Tc, a1, a2, a3, a4, a5, a6))
 
-
+@njitable
 def Zabransky_Quasi_Polynomial_Over_T_Indefinte_Integral(T, Tc, a1, a2, a3, a4, a5, a6):
     Tc2 = Tc*Tc
     Tc3 = Tc2*Tc    
@@ -666,7 +688,8 @@ def Zabransky_Cubic(T, a1, a2, a3, a4):
     """
     T = T/100.
     return R*(((a4*T + a3)*T + a2)*T + a1)
-   
+
+@njitable
 def Zabransky_Cubic_Indefinite_Integral(T, a1, a2, a3, a4):
     T = T/100.
     return 100.*R*T*(T*(T*(T*a4*0.25 + a3/3.) + a2*0.5) + a1)
@@ -676,7 +699,7 @@ def Zabransky_Cubic_Integral(Ta, Tb, a1, a2, a3, a4):
     return (Zabransky_Cubic_Indefinite_Integral(Tb, a1, a2, a3, a4)
             - Zabransky_Cubic_Indefinite_Integral(Ta, a1, a2, a3, a4))
 
-
+@njitable
 def Zabransky_Cubic_Over_T_Indefinite_Integral(T, a1, a2, a3, a4):
     T = T/100.
     return R*(T*(T*(T*a4/3. + a3/2.) + a2) + a1*log(T))
@@ -733,11 +756,11 @@ zabransky_model_builders[2].many = True
 zabransky_model_builders[4].many = True
 
 @TDependentHandleBuilder('Cn.l')
-def HeatCapacityLiquid(handle, CAS, Tb, Tc, omega, MW, similarity_variable, Cn):
+def heat_capacity_liquid_handle(handle, CAS, Tb, Tc, omega, MW, similarity_variable, Cn):
     Cn_g = Cn.g
     for i in zabransky_model_builders: i.add_model(CAS, handle.models)        
     add_model = handle.add_model
-    if CAS in _VDISaturationDict:
+    if CAS in VDI_saturation_dict:
         # NOTE: VDI data is for the saturation curve, i.e. at increasing
         # pressure; it is normally substantially higher than the ideal gas
         # value
@@ -750,7 +773,7 @@ def HeatCapacityLiquid(handle, CAS, Tb, Tc, omega, MW, similarity_variable, Cn):
     # Other
     if MW and similarity_variable:
         add_model(CnHSModel(*Dadgostar_Shaw_Functors,
-                               data=(similarity_variable, MW),
+                               data=(MW, similarity_variable),
                                name=DADGOSTAR_SHAW))
     # Constant models
     if CAS in _Poling:
@@ -817,6 +840,7 @@ def Lastovka_Solid(T, similarity_variable, MW):
                  + (C1*similarity_variable + C2*sim2)*T
                  + (D1*similarity_variable + D2*sim2)*T**2)
 
+@njitable
 def Lastovka_Solid_Indefinite_Integral(T, similarity_variable, MW):
     A1 = 0.013183
     A2 = 0.249381
@@ -837,6 +861,7 @@ def Lastovka_Solid_Integral(Ta, Tb, similarity_variable, MW):
     return (Lastovka_Solid_Indefinite_Integral(Tb, similarity_variable, MW)
             - Lastovka_Solid_Indefinite_Integral(Ta, similarity_variable, MW))
 
+@njitable
 def Lastovka_Solid_Over_T_Indefinite_Integral(T, similarity_variable, MW):
     A1 = 0.013183
     A2 = 0.249381
@@ -896,7 +921,7 @@ LASTOVKA_S = 'Lastovka, Fulem, Becerra and Shaw (2008)'
 PERRY151 = "Perry's Table 2-151"
 
 @TDependentHandleBuilder('Cn.s')
-def HeatCapacitySolid(handle, CAS, similarity_variable, MW):
+def heat_capacity_solid_handle(handle, CAS, similarity_variable, MW):
     Tmin = 0
     Tmax = 2000
     add_model = handle.add_model
@@ -907,15 +932,16 @@ def HeatCapacitySolid(handle, CAS, similarity_variable, MW):
             Tmin = c['Tmin']
             Tmax = c['Tmax']
             data = (c['Const'], c['Lin'], c['Quad'], c['Quadinv'])
-            add_model(CnHSModel(*Perry_151_Functors, data), Tmin, Tmax)
+            add_model(CnHSModel(*Perry_151_Functors, data), Tmin, Tmax,
+                      name=PERRY151)
     if CAS in _CRC_standard:
         Cnc = _CRC_standard[CAS][3]
         if not np.isnan(Cnc):
             add_model(float(Cnc), 200, 350)
     if similarity_variable and MW:
         data = (similarity_variable, MW)
-        add_model(CnHSModel(*Lastovka_Solid_Functors, data), Tmin, Tmax)
+        add_model(CnHSModel(*Lastovka_Solid_Functors, data), Tmin, Tmax,
+                  name=LASTOVKA_S)
 
-
-HeatCapacity = PhaseTPropertyBuilder('Cn', HeatCapacitySolid, HeatCapacityLiquid, HeatCapacityGas)
+heat_capacity_handle = PhaseTPropertyBuilder('Cn', heat_capacity_solid_handle, heat_capacity_liquid_handle, heat_capacity_gas_handle)
 
