@@ -6,7 +6,7 @@ from math import log, exp
 from ..base import sigma, TDependentHandleBuilder, InterpolatedTDependentModel
 from .utils import CASDataReader
 from .._constants import N_A, k
-from .miscdata import _VDISaturationDict, VDI_tabular_data
+from .miscdata import VDI_saturation_dict, VDI_tabular_data
 from .dippr import DIPPR_EQ106
 
 __all__ = ('REFPROP', 'Somayajulu', 'Jasper', 'Brock_Bird', 'Pitzer', 'Sastri_Rao', 'Zuo_Stenby',
@@ -120,7 +120,7 @@ def Mersmann_Kind_surface_tension(T, Tm, Tb, Tc, Pc, n_associated=1):
     return sigma
 
 @TDependentHandleBuilder('sigma')
-def SurfaceTension(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, StielPolar, Hvap_Tb, rhol, Cpl_Tb):
+def surface_tension_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, StielPolar, Hvap_Tb, rhol, Cpl_Tb):
     add_model = handle.add_model
     if CAS in _Mulero_Cachadina:
         _, sigma0, n0, sigma1, n1, sigma2, n2, Tc, Tmin, Tmax = _Mulero_Cachadina[CAS]
@@ -136,7 +136,7 @@ def SurfaceTension(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, StielPolar, Hvap_
         SOMAYAJULU_coeffs = (Tc, A, B, C)
         Tmin = Tt; Tmax = Tc
         add_model(Somayajulu.from_args(SOMAYAJULU_coeffs), Tmin, Tmax)
-    if CAS in _VDISaturationDict:
+    if CAS in VDI_saturation_dict:
         Ts, Ys = VDI_tabular_data(CAS, 'sigma')
         Tmin = Ts[0]
         *Ts, Tmax = Ts
