@@ -2,7 +2,7 @@
 """
 Data and methods for calculating a chemical's permitivity.
 """
-__all__ = ('Permittivity',)
+__all__ = ('permitivity_handle',)
 
 import numpy as np
 from .utils import CASDataReader
@@ -44,7 +44,7 @@ def CRC(T, A, B, C, D):
     return A + B*T + C*T**2 + D*T**3
 
 @TDependentHandleBuilder('epsilon')
-def Permittivity(handle, CAS, Vl):
+def permitivity_handle(handle, CAS, Vl):
     add_model = handle.add_model
     if Vl and CAS == '7732-18-5':
         add_model(IAPWS_Permittivity.from_args((Vl,)))
