@@ -53,52 +53,67 @@ References
 """
 
 
-__all__ = ['EnthalpyVaporization',
-           'Tb_methods', 'Tb', 'Tm_methods', 'Tm', 
-           'Clapeyron', 'Pitzer', 'SMK', 'MK', 'Velasco', 'Riedel', 'Chen', 
-           'Liu', 'Vetere', 'Watson',  'Hfus', 'Hsub']
+__all__ = ('heat_of_vaporization_handle',
+           'normal_boiling_point_temperature', 
+           'normal_melting_point_temperature',
+           'Clapeyron', 'Pitzer', 
+           'SMK', 'MK', 'Velasco',
+           'Riedel', 'Chen', 
+           'Liu', 'Vetere', 'Watson',
+           'heat_of_fusion',
+           'heat_of_sublimation',
+)
 
 import numpy as np
 from ..base import InterpolatedTDependentModel, TDependentHandleBuilder, Hvap
 from .._constants import R, N_A
 from math import log, pi
-from .utils import CASDataReader
-from .miscdata import _CRC_organic, _CRC_inorganic
-from .miscdata import _VDISaturationDict, VDI_tabular_data
+from .utils import CASDataReader, get_from_data_sources
+from .miscdata import organic_data_CRC, inorganic_data_CRC
+from .miscdata import VDI_saturation_dict, VDI_tabular_data
 from ..functional import Z
-from .vapor_pressure import VaporPressure
 from .coolprop import has_CoolProp, PropsSI, coolprop_dict, coolprop_fluids
 from .dippr import DIPPR_EQ106
 
 read = CASDataReader(__file__, 'Phase Change')
 
-
-_Yaws = read('Yaws Boiling Points.tsv')
-_Tm_ON = read('OpenNotebook Melting Points.tsv')
-_GharagheiziHvap = read('Ghazerati Appendix Vaporization Enthalpy.tsv')
-_CRCHvap = read('CRC Handbook Heat of Vaporization.tsv')
-_CRCHfus = read('CRC Handbook Heat of Fusion.tsv')
-_GharagheiziHsub = read('Ghazerati Appendix Sublimation Enthalpy.tsv')
-_Perrys2_150 = read('Table 2-150 Heats of Vaporization of Inorganic and Organic Liquids.tsv')
-_VDI_PPDS_4 = read('VDI PPDS Enthalpies of vaporization.tsv')
-_Alibakhshi_Cs = read('Alibakhshi one-coefficient enthalpy of vaporization.tsv')
+boiling_point_data_Yaws = read('Yaws Boiling Points.tsv')
+melting_point_data_ON = read('OpenNotebook Melting Points.tsv')
+vaporization_data_Gharagheizi = read('Ghazerati Appendix Vaporization Enthalpy.tsv')
+vaporization_data_CRC = read('CRC Handbook Heat of Vaporization.tsv')
+fusion_data_CRC = read('CRC Handbook Heat of Fusion.tsv')
+sublimation_data_Gharagheizi = read('Ghazerati Appendix Sublimation Enthalpy.tsv')
+vaporization_data_Perrys2_150 = read('Table 2-150 Heats of Vaporization of Inorganic and Organic Liquids.tsv')
+vaporization_data_VDI_PPDS_4 = read('VDI PPDS Enthalpies of vaporization.tsv')
+vaporization_data_Alibakhshi_Cs = read('Alibakhshi one-coefficient enthalpy of vaporization.tsv')
 
 ### Boiling Point at 1 atm
 
-CRC_ORG = 'CRC_ORG'
-CRC_INORG = 'CRC_INORG'
-YAWS = 'YAWS'
-PSAT_DEFINITION = 'PSAT_DEFINITION'
-NONE = 'NONE'
+normal_boiling_point_data_sources = {
+    'CRC-Inorganic': inorganic_data_CRC,
+    'CRC-Organic': organic_data_CRC,
+    'Yaws': boiling_point_data_Yaws,
+}
 
-Tb_methods = [CRC_INORG, CRC_ORG, YAWS, PSAT_DEFINITION]
+melting_point_data_sources = {
+    'OPEN-NTBKM': melting_point_data_ON,  
+    'CRC-Inorganic': inorganic_data_CRC,
+    'CRC-Organic': organic_data_CRC,   
+}
+
+fusion_data_sources = {
+    'CRC at Tm': fusion_data_CRC,
+}
+
+sublimation_data_sources = {
+    'Ghazerati Appendix, at 298K': sublimation_data_Gharagheizi,
+}
 
 
-def Tb(CASRN, AvailableMethods=False, Method=None, IgnoreMethods=[PSAT_DEFINITION]):
+def normal_boiling_point_temperature(CASRN, method='Any'):
     r'''
-    This function handles the retrieval of a chemical's boiling
-    point as given by [1]_ [2]_. Lookup is based on CASRNs. Return None if the
-    data is not available.
+    Retrieve the normal boiling point of a chemical as given by [1]_ [2]_.
+    Lookup is based on CASRNs. Return None if the data is not available.
 
     Prefered sources are 'CRC Physical Constants, organic' for organic
     chemicals, and 'CRC Physical Constants, inorganic' for inorganic
@@ -111,97 +126,43 @@ def Tb(CASRN, AvailableMethods=False, Method=None, IgnoreMethods=[PSAT_DEFINITIO
 
     Returns
     -------
-    Tb : float
+    Tb : float or dict(str-float)
         Boiling temperature, [K]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to obtain Tb with the given inputs
 
     Other Parameters
     ----------------
-    Method : string, optional
-        A string for the method name to use, as defined by constants in
-        Tb_methods
-    AvailableMethods : bool, optional
-        If True, function will determine which methods can be used to obtain
-        Tb for the desired chemical, and will return methods instead of Tb
-    IgnoreMethods : list, optional
-        A list of methods to ignore in obtaining the full list of methods,
-        useful for for performance reasons and ignoring inaccurate methods
+    method : string, optional
+        The method name to use. Accepted methods are 'CRC-Organic', 'CRC-Inorganic', 
+        and 'YAWS'. If method is "Any", the first available
+        value from these methods will returned. If method is "All",
+        a dictionary of method results will be returned.
 
     Notes
     -----
     A total of four methods are available for this function. They are:
 
-        * 'CRC_ORG', a compillation of data on organics
+        * 'CRC-Organic', a compillation of data on organics
           as published in [1]_.
-        * 'CRC_INORG', a compillation of data on
+        * 'CRC-Inorganic', a compillation of data on
           inorganic as published in [1]_.
         * 'YAWS', a large compillation of data from a
           variety of sources; no data points are sourced in the work of [2]_.
-        * 'PSAT_DEFINITION', calculation of boiling point from a
-          vapor pressure calculation. This is normally off by a fraction of a
-          degree even in the best cases. Listed in IgnoreMethods by default
-          for performance reasons.
 
     Examples
     --------
-    >>> Tb('7732-18-5')
+    >>> normal_boiling_point_temperature('7732-18-5')
     373.124
 
     '''
-    def list_methods():
-        methods = []
-        if CASRN in _CRC_inorganic and not np.isnan(_CRC_inorganic.at[CASRN, 'Tb']):
-            methods.append(CRC_INORG)
-        if CASRN in _CRC_organic and not np.isnan(_CRC_organic.at[CASRN, 'Tb']):
-            methods.append(CRC_ORG)
-        if CASRN in _Yaws:
-            methods.append(YAWS)
-        if PSAT_DEFINITION not in IgnoreMethods:
-            try:
-                # For some chemicals, vapor pressure range will exclude Tb
-                VaporPressure(CASRN=CASRN).solve_prop(101325.)
-                methods.append(PSAT_DEFINITION)
-            except:  # pragma: no cover
-                pass
-        if IgnoreMethods:
-            for Method in IgnoreMethods:
-                if Method in methods:
-                    methods.remove(Method)
-        methods.append(NONE)
-        return methods
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
-        Method = list_methods()[0]
-
-    if Method == CRC_INORG:
-        return float(_CRC_inorganic.at[CASRN, 'Tb'])
-    elif Method == CRC_ORG:
-        return float(_CRC_organic.at[CASRN, 'Tb'])
-    elif Method == YAWS:
-        return float(_Yaws.at[CASRN, 'Tb'])
-    elif Method == PSAT_DEFINITION:
-        return VaporPressure(CASRN=CASRN).solve_prop(101325.)
-    elif Method == NONE:
-        return None
-    else:
-        raise Exception('Failure in in function')
+    return get_from_data_sources(normal_boiling_point_data_sources, CASRN, 'Tb', method)
 
 
 ### Melting Point
 
-
-OPEN_NTBKM = 'OPEN_NTBKM'
-
-Tm_methods = [OPEN_NTBKM, CRC_INORG, CRC_ORG]
-
-
-def Tm(CASRN, AvailableMethods=False, Method=None, IgnoreMethods=[]):
+def normal_melting_point_temperature(CASRN, method='Any'):
     r'''
-    This function handles the retrieval of a chemical's melting
-    point as given by [3]_ [4]_. Lookup is based on CASRNs. Return None if 
-    the data is not available.
+    Retrieve the melting point temperature of a chemical as given by [3]_ [4]_.
+    Lookup is based on CASRNs. Return None if the data is not available.
 
     Prefered sources are 'Open Notebook Melting Points', with backup sources
     'CRC Physical Constants, organic' for organic chemicals, and
@@ -215,72 +176,39 @@ def Tm(CASRN, AvailableMethods=False, Method=None, IgnoreMethods=[]):
 
     Returns
     -------
-    Tm : float
+    Tm : float or dict(str-float)
         Melting temperature, [K]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to obtain Tm with the given inputs
 
     Other Parameters
     ----------------
-    Method : string, optional
-        A string for the method name to use, as defined by constants in
-        Tm_methods
-    AvailableMethods : bool, optional
-        If True, function will determine which methods can be used to obtain
-        Tm for the desired chemical, and will return methods instead of Tm
-    IgnoreMethods : list, optional
-        A list of methods to ignore in obtaining the full list of methods
+    method : string, optional
+        The method name to use. Accepted methods are 'OPEN-NTBKM', 'CRC-Organic', 
+        and 'CRC-Inorganic'. If method is "Any", the first available
+        value from these methods will returned. If method is "All",
+        a dictionary of method results will be returned.
 
     Notes
     -----
     A total of three sources are available for this function. They are:
 
-        * 'OPEN_NTBKM, a compillation of data on organics
+        * 'OPEN-NTBKM, a compillation of data on organics
           as published in [1]_ as Open Notebook Melting Points; Averaged 
           (median) values were used when
           multiple points were available. For more information on this
           invaluable and excellent collection, see
           http://onswebservices.wikispaces.com/meltingpoint.
-        * 'CRC_ORG', a compillation of data on organics
+        * 'CRC-Organic', a compillation of data on organics
           as published in [2]_.
-        * 'CRC_INORG', a compillation of data on
+        * 'CRC-Inorganic', a compillation of data on
           inorganic as published in [2]_.
 
     Examples
     --------
-    >>> Tm(CASRN='7732-18-5')
+    >>> melting_point_temperature(CASRN='7732-18-5')
     273.15
 
     '''
-    def list_methods():
-        methods = []
-        if CASRN in _Tm_ON.index:
-            methods.append(OPEN_NTBKM)
-        if CASRN in _CRC_inorganic and not np.isnan(_CRC_inorganic.at[CASRN, 'Tm']):
-            methods.append(CRC_INORG)
-        if CASRN in _CRC_organic and not np.isnan(_CRC_organic.at[CASRN, 'Tm']):
-            methods.append(CRC_ORG)
-        if IgnoreMethods:
-            for Method in IgnoreMethods:
-                if Method in methods:
-                    methods.remove(Method)
-        methods.append(NONE)
-        return methods
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
-        Method = list_methods()[0]
-
-    if Method == OPEN_NTBKM:
-        return float(_Tm_ON.at[CASRN, 'Tm'])
-    elif Method == CRC_INORG:
-        return float(_CRC_inorganic.at[CASRN, 'Tm'])
-    elif Method == CRC_ORG:
-        return float(_CRC_organic.at[CASRN, 'Tm'])
-    elif Method == NONE:
-        return None
-    else:
-        raise Exception('Failure in in function')
+    return get_from_data_sources(melting_point_data_sources, CASRN, 'Tm', method)
 
 
 ### Enthalpy of Vaporization at T
@@ -714,18 +642,19 @@ def VDI_PPDS(T, Tc, A, B, C, D, E):
     return R*Tc*(A*tau**(1/3.) + B*tau**(2/3.) + C*tau + D*tau**2 + E*tau**6)
 
 @TDependentHandleBuilder('Hvap')
-def EnthalpyVaporization(handle, CAS, Tb, Tc, Pc, omega, similarity_variable, Psat, V):
+def heat_of_vaporization_handle(handle, CAS, Tb, Tc, Pc, omega, 
+                                similarity_variable, Psat, V):
     # if has_CoolProp and self.CASRN in coolprop_dict:
     #     methods.append(COOLPROP)
     #     self.CP_f = coolprop_fluids[self.CASRN]
     #     Tmins.append(self.CP_f.Tt); Tmaxs.append(self.CP_f.Tc)
     add_model = handle.add_model
-    if CAS in _Perrys2_150:
-        _, Tc, C1, C2, C3, C4, Tmin, Tmax = _Perrys2_150[CAS]
+    if CAS in vaporization_data_Perrys2_150:
+        _, Tc, C1, C2, C3, C4, Tmin, Tmax = vaporization_data_Perrys2_150[CAS]
         data = (Tc, C1, C2, C3, C4)
         add_model(DIPPR_EQ106.from_args(data), Tmin, Tmax)
-    if CAS in _VDI_PPDS_4:
-        _,  MW, Tc, A, B, C, D, E = _VDI_PPDS_4[CAS]
+    if CAS in vaporization_data_VDI_PPDS_4:
+        _,  MW, Tc, A, B, C, D, E = vaporization_data_VDI_PPDS_4[CAS]
         add_model(VDI_PPDS.from_args(data=(Tc, A, B, C, D, E)), 0, Tc)
     data = (Tb, Tc, Pc)
     if all(data):
@@ -737,24 +666,25 @@ def EnthalpyVaporization(handle, CAS, Tb, Tc, Pc, omega, similarity_variable, Ps
     if all(data):
         for f in (MK, SMK, Velasco, Pitzer):
             add_model(f.from_args(data), 0, Tc)
-    if CAS in _VDISaturationDict:
+    if CAS in VDI_saturation_dict:
         Ts, Hvaps = VDI_tabular_data(CAS, 'Hvap')
         add_model(InterpolatedTDependentModel(Ts, Hvaps, Ts[0], Ts[-1]))
     if Tc:
-        if CAS in _Alibakhshi_Cs:
-            C = float(_Alibakhshi_Cs.at[CAS, 'C'])
+        if CAS in vaporization_data_Alibakhshi_Cs:
+            C = float(vaporization_data_Alibakhshi_Cs.at[CAS, 'C'])
             add_model(Alibakhshi.from_args(data=(Tc, C)), 0, Tc)
-        if CAS in _CRCHvap and not np.isnan(_CRCHvap.at[CAS, 'HvapTb']):
-            Tb = float(_CRCHvap.at[CAS, 'Tb'])
-            Hvap = float(_CRCHvap.at[CAS, 'HvapTb'])
-            data = dict(Hvap_ref=Hvap, T_ref=Tb, Tc=Tc, exponent=0.38)
-            add_model(Watson.from_kwargs(data), 0, 10e6)
-        if CAS in _CRCHvap and not np.isnan(_CRCHvap.at[CAS, 'Hvap298']):
-            Hvap = float(_CRCHvap.at[CAS, 'Hvap298'])
-            data = dict(Hvap_ref=Hvap, T_ref=298., Tc=Tc, exponent=0.38)
-            add_model(Watson.from_kwargs(data), 0, 10e6)
-        if CAS in _GharagheiziHvap.index:
-            Hvap = float(_GharagheiziHvap.at[CAS, 'Hvap298'])
+        if CAS in vaporization_data_CRC:
+            Hvap = float(vaporization_data_CRC.at[CAS, 'HvapTb'])
+            if not np.isnan(Hvap):
+                Tb = float(vaporization_data_CRC.at[CAS, 'Tb'])
+                data = dict(Hvap_ref=Hvap, T_ref=Tb, Tc=Tc, exponent=0.38)
+                add_model(Watson.from_kwargs(data), 0, 10e6)
+            Hvap = float(vaporization_data_CRC.at[CAS, 'Hvap298'])
+            if not np.isnan(Hvap):
+                data = dict(Hvap_ref=Hvap, T_ref=298., Tc=Tc, exponent=0.38)
+                add_model(Watson.from_kwargs(data), 0, 10e6)
+        if CAS in vaporization_data_Gharagheizi:
+            Hvap = float(vaporization_data_Gharagheizi.at[CAS, 'Hvap298'])
             data = dict(Hvap_ref=Hvap, T_ref=298., Tc=Tc, exponent=0.38)
             add_model(Watson.from_kwargs(data), 0, 10e6)
 
@@ -762,76 +692,19 @@ def EnthalpyVaporization(handle, CAS, Tb, Tc, Pc, omega, similarity_variable, Ps
 ### Heat of Fusion
 
 
-def Hfus(T=298.15, P=101325, MW=None, AvailableMethods=False, Method=None, CASRN=''):  # pragma: no cover
-    '''This function handles the calculation of a chemical's enthalpy of fusion.
-    Generally this, is used by the chemical class, as all parameters are passed.
-    Calling the function directly works okay.
-
-    Enthalpy of fusion is a weak function of pressure, and its effects are
-    neglected.
-
-    This API is considered experimental, and is expected to be removed in a
-    future release in favor of a more complete object-oriented interface.
+def heat_of_fusion(CASRN, method='Any'):
+    '''
+    Retrieve the heat of fusion of a chemical. Enthalpy of fusion is a
+    weak function of pressure, and its effects are neglected.
 
     '''
-    def list_methods():
-        methods = []
-        if CASRN in _CRCHfus:
-            methods.append('CRC, at melting point')
-        methods.append('None')
-        return methods
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
-        Method = list_methods()[0]
-    # This is the calculate, given the method section
-    if Method == 'CRC, at melting point':
-        _Hfus = _CRCHfus.at[CASRN, 'Hfus']
-    elif Method == 'None' or not MW:
-        _Hfus = None
-    else:
-        raise Exception('Failure in in function')
-    return _Hfus
-#print Hfus(CASRN='75-07-0')
-#['CRC, at melting point', 'None']
+    return get_from_data_sources(fusion_data_sources, CASRN, 'Hfus', method)
 
 
-### Heat of Sublimation
-
-
-def Hsub(T=298.15, P=101325, AvailableMethods=False, Method=None, CASRN=''):  # pragma: no cover
-    '''This function handles the calculation of a chemical's enthalpy of sublimation.
-    Generally this, is used by the chemical class, as all parameters are passed.
-
-
-    This API is considered experimental, and is expected to be removed in a
-    future release in favor of a more complete object-oriented interface.
+def heat_of_sublimation(CASRN, method='Any'):  # pragma: no cover
     '''
-    def list_methods():
-        methods = []
-#        if Hfus(T=T, P=P, MW=MW, CASRN=CASRN) and Hvap(T=T, P=P, MW=MW, CASRN=CASRN):
-#            methods.append('Hfus + Hvap')
-        if CASRN in _GharagheiziHsub:
-            methods.append('Ghazerati Appendix, at 298K')
-        methods.append('None')
-        return methods
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
-        Method = list_methods()[0]
-    # This is the calculate, given the method section
-#    if Method == 'Hfus + Hvap':
-#        p1 = Hfus(T=T, P=P, MW=MW, CASRN=CASRN)
-#        p2 = Hvap(T=T, P=P, MW=MW, CASRN=CASRN)
-#        if p1 and p2:
-#            _Hsub = p1 + p2
-#        else:
-#            _Hsub = None
-    if Method == 'Ghazerati Appendix, at 298K':
-        _Hsub = float(_GharagheiziHsub.at[CASRN, 'Hsub'])
-    elif Method == 'None':
-        return None
-    else:
-        raise Exception('Failure in in function')
-    return _Hsub
+    Retrieve the enthalpy of sublimation. 
+    
+    '''
+    return get_from_data_sources(sublimation_data_sources, CASRN, 'Hsub', method)
 
