@@ -9,11 +9,11 @@ from .._constants import R, N_A, k
 from math import log, exp
 from .utils import CASDataReader
 from ..functional import horner_polynomial
-from .miscdata import _VDISaturationDict, VDI_tabular_data
+from .miscdata import VDI_saturation_dict, VDI_tabular_data
 from .dippr import DIPPR_EQ100, DIPPR_EQ102
 
 
-__all__ = ('ThermalConductivity',
+__all__ = ('thermal_conductivity_handle',
            'Sheffy_Johnson', 'Sato_Riedel', 'Lakshmi_Prasad', 'Gharagheizi_liquid',
            'Nicola_original', 'Nicola', 'Bahadori_liquid', 'Mersmann_Kind_thermal_conductivity_liquid',
            'DIPPR9G', 'Missenard', 'Eucken', 'Eucken_modified', 'DIPPR9B_linear',
@@ -115,7 +115,7 @@ def Missenard(T, P, Tc, Pc, kl_models):
     return kl.evaluate(T)*(1. + Q*Pr**0.7)
 
 @TPDependentHandleBuilder('kappa.l')
-def ThermalConductivityLiquid(handle, CAS, MW, Tm, Tb, Tc, Pc, omega, Hfus):
+def thermal_conductivity_liquid_handle(handle, CAS, MW, Tm, Tb, Tc, Pc, omega, Hfus):
     add_model = handle.add_model
     if CAS in _Perrys2_315:
         _, C1, C2, C3, C4, C5, Tmin, Tmax = _Perrys2_315[CAS]
@@ -124,7 +124,7 @@ def ThermalConductivityLiquid(handle, CAS, MW, Tm, Tb, Tc, Pc, omega, Hfus):
     if CAS in _VDI_PPDS_9:
         _,  A, B, C, D, E = _VDI_PPDS_9[CAS]
         add_model(horner_polynomial.from_kwargs({'coeffs':(E, D, C, B, A)}))
-    if CAS in _VDISaturationDict:
+    if CAS in VDI_saturation_dict:
         Ts, Ys = VDI_tabular_data(CAS, 'K (l)')
         Tmin = Ts[0]
         Tmax = Ts[-1]
@@ -381,13 +381,13 @@ def Chung_dense(T, P, MW, Tc, Vc, omega, Cp, Vg, mug, dipole, association=0):
 
 
 @TPDependentHandleBuilder('kappa.g')
-def ThermalConductivityGas(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, dipole, Vg, Cp, mug):
+def thermal_conductivity_gas_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, dipole, Vg, Cp, mug):
     data = (MW, Tb, Pc, omega)
     add_model = handle.add_model
     if all(data):
         add_model(Gharagheizi_gas.from_args(data))
     data = (MW, Cp, mug, Tc)
-    if CAS in _VDISaturationDict:
+    if CAS in VDI_saturation_dict:
         Ts, Ys = VDI_tabular_data(CAS, 'K (g)')
         add_model(InterpolatedTDependentModel(Ts, Ys))
     if CAS in _VDI_PPDS_10:
@@ -420,5 +420,7 @@ def ThermalConductivityGas(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, dipole, V
     #     _, *data, Tmin, Tmax = _Perrys2_314[CAS]
     #     add_model(DIPPR9B_linear(data), Tmin, Tmax)
 
-ThermalConductivity = PhaseTPPropertyBuilder('kappa', None, ThermalConductivityLiquid, ThermalConductivityGas)
+thermal_conductivity_handle = PhaseTPPropertyBuilder('kappa', None,
+                                                     thermal_conductivity_liquid_handle,
+                                                     thermal_conductivity_gas_handle)
 
