@@ -215,8 +215,8 @@ def Wagner(T, Tc, Pc, a, b, c, d):
     τ = 1.0 - Tr
     return Pc * exp((a*τ + b*τ**1.5 + c*τ**2.5 + d*τ**5) / Tr)
 
-@Psat
-def Boiling_Critical_Relation(T, Tc, Pc, Tbr, h):
+@Psat(ref="[6]_")
+def Boiling_Critical_Relation(T, Tb, Tc, Pc):
     r"""
     Notes
     -----
@@ -238,13 +238,13 @@ def Boiling_Critical_Relation(T, Tc, Pc, Tbr, h):
     15209.467273093938
     
     """
+    h, Tbr = calculate_Boiling_Critical_Relation_term(Tb, Tc, Pc)
     return exp(h * (1 - Tc / T)) * Pc
 
-@Boiling_Critical_Relation.wrapper(ref="[6]_")
-def Boiling_Critical_Relation(Tb, Tc, Pc):
+def calculate_Boiling_Critical_Relation_term(Tb, Tc, Pc):
     Tbr = Tb / Tc
     h = Tbr * log(Pc / 101325.0) / (1 - Tbr)
-    return {'Tc':Tc, 'Pc':Pc, 'Tbr': Tbr, 'h':h}
+    return h, Tbr
 
 @Psat(ref="[7]_")
 def Lee_Kesler(T, Tc, Pc, ω):
@@ -333,7 +333,8 @@ def Sanjari(T, Tc, Pc, ω):
         
         f^{(2)} = a_9 + \frac{a_{10}}{T_r} + a_{11}\ln T_r + a_{12} T_r^{1.9}
         
-    Although developed for refrigerants, this model should have some general predictive ability.
+    Although developed for refrigerants, this model should have some general
+    predictive ability.
     
     a[1-12] are as follows:
     6.83377, -5.76051, 0.90654, -1.16906,
@@ -402,7 +403,7 @@ def Edalat(T, Tc, Pc, ω):
     return exp(lnPr) * Pc
 
 @TDependentHandleBuilder('Psat')
-def VaporPressure(handle, CAS, Tb, Tc, Pc, omega):
+def vapor_pressure_handle(handle, CAS, Tb, Tc, Pc, omega):
     add_model = handle.add_model
     if CAS in _WagnerMcGarry:
         _, a, b, c, d, Pc, Tc, Tmin = _WagnerMcGarry[CAS]
