@@ -10,7 +10,7 @@ from math import log, exp
 from .utils import CASDataReader
 from ..functional import horner_polynomial
 from ..base import InterpolatedTDependentModel, mu, TPDependentHandleBuilder, TDependentModel, PhaseTPPropertyBuilder
-from .miscdata import _VDISaturationDict, VDI_tabular_data
+from .miscdata import VDI_saturation_dict, VDI_tabular_data
 # from .electrochem import _Laliberte_Viscosity_ParametersDict, Laliberte_viscosity
 from .dippr import DIPPR_EQ101, DIPPR_EQ102
 
@@ -79,9 +79,9 @@ def Lucas(T, P, Tc, Pc, omega, P_sat, mu):
     return (1. + D*(dPr/2.118)**A)/(1. + C*omega*dPr)*mu.l(T)
 
 @TPDependentHandleBuilder('mu.l')
-def ViscosityLiquid(handle, CAS, MW, Tm, Tc, Pc, Vc, omega, Psat, Vl):
+def viscosity_liquid_handle(handle, CAS, MW, Tm, Tc, Pc, Vc, omega, Psat, Vl):
     add_model = handle.add_model
-    if CAS in _VDISaturationDict:
+    if CAS in VDI_saturation_dict:
         Ts, Ys = VDI_tabular_data(CAS, 'Mu (l)')
         add_model(InterpolatedTDependentModel(Ts, Ys, Ts[0], Ts[-1]))
     if CAS in _Dutt_Prasad:
@@ -181,7 +181,7 @@ LUCAS_GAS = 'LUCAS_GAS'
 
 
 @TPDependentHandleBuilder('mu.g')
-def ViscosityGas(handle, CAS, MW, Tc, Pc, Zc, dipole):
+def viscosity_gas_handle(handle, CAS, MW, Tc, Pc, Zc, dipole):
     add_model = handle.add_model
     if CAS in _Perrys2_312:
         _, C1, C2, C3, C4, Tmin, Tmax = _Perrys2_312[CAS]
@@ -204,13 +204,15 @@ def ViscosityGas(handle, CAS, MW, Tc, Pc, Zc, dipole):
         # Intelligently set limit
         # GHARAGHEIZI turns nonsensical at ~15 K, YOON_THODOS fine to 0 K,
         # same as STIEL_THODOS
-    if CAS in _VDISaturationDict:
+    if CAS in VDI_saturation_dict:
         Ts, Ys = VDI_tabular_data(CAS, 'Mu (g)')
         Tmin = Ts[0]
         Tmax = Ts[-1]
         add_model(InterpolatedTDependentModel(Ts, Ys, Tmin, Tmax))
 
-Viscosity = PhaseTPPropertyBuilder('mu', None, ViscosityLiquid, ViscosityGas)
+viscosity_handle = PhaseTPPropertyBuilder('mu', None,
+                                          viscosity_liquid_handle,
+                                          viscosity_gas_handle)
 
 # %% Other
 
