@@ -50,12 +50,12 @@ from .. import functional as fn
 from .utils import CASDataReader
 from .._constants import R
 from .virial import BVirial_Pitzer_Curl, BVirial_Abbott, BVirial_Tsonopoulos, BVirial_Tsonopoulos_extended
-from .miscdata import _VDISaturationDict, VDI_tabular_data
+from .miscdata import VDI_saturation_dict, VDI_tabular_data
 from .dippr import DIPPR_EQ105
 # from .electrochem import _Laliberte_Density_ParametersDict, Laliberte_Density
 from ..base import V, InterpolatedTDependentModel, TPDependentModel, TPDependentHandleBuilder, PhaseTPPropertyBuilder
 
-__all__ = ('Volume',
+__all__ = ('volume_handle',
            'Yen_Woods',
            'Rackett',
            'Yamada_Gunn', 
@@ -87,8 +87,8 @@ _CRC_virial = read('CRC Virial polynomials.tsv')
 
 # %% Liquids
 
-@V.l
-def Yen_Woods(T, Tc, Vc, A, B, D):
+@V.l(ref="[1]_")
+def Yen_Woods(T, Tc, Vc, Zc):
     r'''
     Notes
     -----
@@ -127,10 +127,10 @@ def Yen_Woods(T, Tc, Vc, A, B, D):
 
     '''
     Tr = T/Tc
+    A, B, D = calculate_Yen_Woods_terms(Tc, Vc, Zc)
     return Vc/(1 + A*(1-Tr)**(1/3.) + B*(1-Tr)**(2/3.) + D*(1-Tr)**(4./3.))
 
-@Yen_Woods.wrapper(ref="[1]_")
-def Yen_Woods(Tc, Vc, Zc):
+def calculate_Yen_Woods_terms(Tc, Vc, Zc):
     Zc2 = Zc*Zc
     Zc3 = Zc2*Zc
     A = 17.4425 - 214.578*Zc + 989.625*Zc2 - 1522.06*Zc3
@@ -139,7 +139,7 @@ def Yen_Woods(Tc, Vc, Zc):
     else:
         B = 60.2091 - 402.063*Zc + 501.0*Zc2 + 641.0*Zc3
     D = 0.93 - B
-    return {'Tc':Tc, 'Vc':Vc, 'A':A, 'B':B, 'D':D}
+    return (A, B, D)
 
 @V.l(ref='[2]_')
 def Rackett(T, Tc, Pc, Zc):
@@ -169,8 +169,8 @@ def Rackett(T, Tc, Pc, Zc):
     '''
     return R*Tc/Pc*Zc**(1. + (1. - T/Tc)**(2./7.))
 
-@V.l
-def Yamada_Gunn(T, P, Tc, k1, k2):
+@V.l(ref='[3]_ [4]_')
+def Yamada_Gunn(T, P, Tc, Pc, omega):
     r'''
     Notes
     -----
@@ -196,13 +196,13 @@ def Yamada_Gunn(T, P, Tc, k1, k2):
     1.9511311612842117e-08
 
     '''
+    k1, k2 = calculate_Yamada_Gunn_terms(Tc, Pc, omega)
     return k1 * k2**(1 + (1 - T/Tc)**(2/7.))
 
-@Yamada_Gunn.wrapper(ref='[3]_ [4]_')
-def Yamada_Gunn(Tc, Pc, omega):
+def calculate_Yamada_Gunn_terms(Tc, Pc, omega):
     k1 = R*Tc/Pc
     k2 = (0.29056 - 0.08775*omega)
-    return {'Tc':Tc, 'k1': k1, 'k2': k2}
+    return k1, k2
 
 @V.l(ref="[5]_")
 def Townsend_Hales(T, Tc, Vc, omega):
@@ -424,8 +424,8 @@ def Campbell_Thodos(T, Tb, Tc, Pc, MW, dipole=None, has_hydroxyl=False):
     Vs = R*Tc/(Pc*101325)*Zra**(1+(1-Tr)**(2./7.))
     return Vs
 
-@V.l
-def SNM0(T, Tc, Vc, m, delta_SRK):
+@V.l(equation='Mchaweh-Moshfeghian', ref='[9]_')
+def SNM0(T, Tc, Vc, omega, delta_SRK):
     r'''
     Notes
     -----
@@ -457,6 +457,7 @@ def SNM0(T, Tc, Vc, m, delta_SRK):
     3.493288100008123e-05
     
     '''
+    m = calculate_SNM0_term(omega)
     Tr = T/Tc
     alpha_SRK = (1. + m*(1. - Tr**0.5))**2
     tau = 1. - Tr/alpha_SRK
@@ -464,10 +465,9 @@ def SNM0(T, Tc, Vc, m, delta_SRK):
     V0 = 1./rho0
     return Vc*V0/(1. + delta_SRK*(alpha_SRK - 1.)**(1/3.)) if delta_SRK else Vc*V0
 
-@SNM0.wrapper(equation='Mchaweh-Moshfeghian', ref='[9]_')
-def SNM0(Tc, Vc, omega, delta_SRK=None):
-    m = 0.480 + 1.574*omega - 0.176*omega*omega
-    return {'Tc':Tc, 'Vc':Vc, 'm':m, 'delta_SRK':delta_SRK}
+
+def calculate_SNM0_term(omega):
+    return 0.480 + 1.574*omega - 0.176*omega*omega
 
 @V.l(doc='auto-header')
 def CRC_Inorganic(T, rho0, k, Tm, MW):
@@ -579,7 +579,8 @@ def Costald_Compressed(T, P, Psat, Tc, Pc, omega, Vs):
     return Vs(T, P)*(1 - C*log((B + P)/(B + Psat(T))))
 
 @TPDependentHandleBuilder('V.l')
-def VolumeLiquid(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, Psat, eos, dipole, has_hydroxyl):
+def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
+                         omega, Psat, eos, dipole, has_hydroxyl):
     Tmin = 50
     Tmax = 1000
     all_ = all
@@ -596,7 +597,7 @@ def VolumeLiquid(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, Psat, eos, dipole,
         _, C1, C2, C3, C4, Tmin, Tmax = _Perry_l[CAS]
         data = (C1, C2, C3, C4, True)
         add_model(DIPPR_EQ105.from_args(data), Tmin, Tmax)
-    if CAS in _VDISaturationDict:
+    if CAS in VDI_saturation_dict:
         Ts, Vls = VDI_tabular_data(CAS, 'Volume (l)')
         model = InterpolatedTDependentModel(Ts, Vls,
                                             Tmin=Ts[0], Tmax=Ts[-1])
@@ -674,7 +675,7 @@ def CRCVirial(T, P, a1, a2, a3, a4, a5):
     return ideal_gas(T, P) + (a1 + a2*t + a3*t**2 + a4*t**3 + a5*t**4)/1e6
 
 @TPDependentHandleBuilder('V.g')
-def VolumeGas(handle, CAS, Tc, Pc, omega, eos):
+def volume_gas_handle(handle, CAS, Tc, Pc, omega, eos):
     add_model = handle.add_model
     # no point in getting Tmin, Tmax
     if all((Tc, Pc, omega)):
@@ -717,11 +718,15 @@ def Goodman(T, Tt, V_l):
     return (1.28 - 0.16*(T/Tt))*V_l
 
 @TPDependentHandleBuilder('V.s')
-def VolumeSolid(handle, CAS):
+def volume_solid_handle(handle, CAS):
     if CAS in _CRC_inorg_s_const:
         CRC_INORG_S_Vm = float(_CRC_inorg_s_const.at[CAS, 'Vm'])
         handle.add_model(CRC_INORG_S_Vm, 0, 1e6, 0, 1e12)
 
 
-Volume = PhaseTPPropertyBuilder('V', VolumeSolid, VolumeLiquid, VolumeGas)
+volume_handle = PhaseTPPropertyBuilder('V',
+                                       volume_solid_handle, 
+                                       volume_liquid_handle,
+                                       volume_gas_handle)
+
 
