@@ -5,6 +5,7 @@ Created on Fri Dec 13 08:08:14 2019
 @author: yoelr
 """
 
+from . import name_utils
 from . import pickle_utils
 from . import repr_utils
 from . import decorator_utils
@@ -15,8 +16,10 @@ from . import assert_utils
 from . import var_utils
 from . import registry
 from . import colors
+from . import plot_utils
 
-__all__ = (*pickle_utils.__all__,
+__all__ = (*name_utils.__all__,
+           *pickle_utils.__all__,
            *repr_utils.__all__,
            *decorator_utils.__all__,
            *other_utils.__all__,
@@ -25,8 +28,11 @@ __all__ = (*pickle_utils.__all__,
            *assert_utils.__all__,
            *var_utils.__all__,
            *registry.__all__,
-           *colors.__all__)
+           *colors.__all__,
+           *plot_utils.__all__,
+)
 
+from .name_utils import *
 from .pickle_utils import *
 from .repr_utils import *
 from .decorator_utils import *
@@ -36,4 +42,5 @@ from .cache import *
 from .assert_utils import *
 from .var_utils import *
 from .registry import *
-from .colors import *
\ No newline at end of file
+from .colors import *
+from .plot_utils import *
\ No newline at end of file
